@@ -3,6 +3,7 @@
 % mozart0.tex
 %
 %%%%%%%%%%%%%%%%
+\def\Lrp#1{\centerbar{\liftpause{#1}}}
 \normalmusicsize%
 \tracingstats=2\relax
 \hsize=524pt
@@ -19,12 +20,10 @@
 \parindent 0pt
 \elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
 \stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
-\setsize2{\normalvalue}%
-\startpiece\addspace\afterruleskip%            
+\startpiece\addspace\afterruleskip%
 \znotes&\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
 % bar  1
 \def\Notes{\vnotes1.41\elemskip}%
-\def\Notesp{\vnotes1.73\elemskip}%
 \def\NOtes{\vnotes2.00\elemskip}%
 \NOtes\ibl1{'E}0\qb1C\qb1G\qb1E\tbl1\qb1G\ibl1E0\qb1C\qb1G\qb1E%
 \tbl1\qb1G&\hl{'c}\sk\sk\sk\ql e\sk\ql g\en%
