@@ -3,8 +3,7 @@
 % title.tex
 %
 %%%%%%%%%%%%%%%%
-\def\fixdrop{\advance\sysno by 1\ifcase\sysno%
-\figdrop= 4     \fi}%
+\def\Lrp#1{\centerbar{\liftpause{#1}}}
 \normalmusicsize%
 \tracingstats=2\relax
 \hsize=266pt
@@ -18,14 +17,11 @@
 \elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
 \stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
 \nostartrule
-\setsize1{\normalvalue}%
 \Largemusicsize%
-\startpiece\addspace\afterruleskip%            
+\startpiece\addspace\afterruleskip%
 \znotes\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
 % bar  1
-\fixdrop%
 \def\Notes{\vnotes1.41\elemskip}%
-\def\Notesp{\vnotes1.73\elemskip}%
 \def\NOtes{\vnotes2.00\elemskip}%
 \Notes\ibbu1{'a}0\qb1c\qs\qb1{`g}\tbu1\qb1g\en%
 \NOtes\cchar{-6}{\ppff{sf}}\ibu1{'a}0\islurd8a\bigfl a\qb1a\tslur8{`g}%
