@@ -9,10 +9,6 @@
 #include "analyze.h"
 
 
-#ifndef GLOBALS_H
-#include "globals.h"
-#endif
-
 #ifndef MTX_H
 #include "mtx.h"
 #endif
@@ -40,7 +36,9 @@
 
 void includeStartString(void)
 {
-  short voice, mus, FORLIM;
+  voice_index voice;
+  paragraph_index0 mus;
+  voice_index FORLIM;
   char STR1[256];
   char STR2[256];
 
@@ -69,11 +67,11 @@ static char *describe(char *Result, short nbar, short extra)
 
 void testParagraph(void)
 {
-  short extra, voice, l;
-  short leader = 0;
-  short mus, nbar;
-  short nv = 0;
-  short FORLIM;
+  voice_index0 voice;
+  voice_index0 leader = 0, nv = 0;
+  paragraph_index0 mus;
+  short extra, l, nbar;
+  voice_index0 FORLIM;
   char STR2[256];
   char STR3[256];
 
@@ -147,9 +145,9 @@ void testParagraph(void)
 
 void describeParagraph(void)
 {
-  short voice;
+  voice_index0 voice;
   char STR2[256];
-  short FORLIM;
+  voice_index0 FORLIM;
 
   printf("---- Paragraph %d starting at line %d bar %d\n",
 	 paragraph_no, orig_line_no[0], bar_no);
@@ -161,7 +159,9 @@ void describeParagraph(void)
 
 /* static variables for paragraphSetup: */
 struct LOC_paragraphSetup {
-  short *voice, k, l;
+  voice_index0 *voice;
+  short l;
+  voice_index0 k;
   char P_keep[256], w[256];
   boolean is_labelled;
 } ;
@@ -214,7 +214,7 @@ static void maybeChords(short i, struct LOC_paragraphSetup *LINK)
 
 static void analyzeParagraph(struct LOC_paragraphSetup *LINK)
 {
-  short i, FORLIM;
+  paragraph_index i, FORLIM;
 
   *LINK->voice = 0;
   bottom = 0;
@@ -274,9 +274,9 @@ static void analyzeParagraph(struct LOC_paragraphSetup *LINK)
 
 static void obliterate(struct LOC_paragraphSetup *LINK)
 {
-  short i;
+  paragraph_index i;
   char new_only[256];
-  short FORLIM;
+  paragraph_index FORLIM;
 
   *new_only = '\0';
   FORLIM = para_len;
@@ -298,7 +298,7 @@ static void obliterate(struct LOC_paragraphSetup *LINK)
 }
 
 
-void paragraphSetup(short *voice_)
+void paragraphSetup(voice_index0 *voice_)
 {
   struct LOC_paragraphSetup V;
 
