@@ -26,6 +26,7 @@ typedef unsigned  boolean;
 #define true 1
 
 extern int _EscIO (int);
+extern int _EscIO2 (int errorcode, char* filename);
 extern int _Escape (int);
 extern int P_eof (FILE *);
 extern int _SETIO (int, int);
@@ -44,7 +45,7 @@ extern char **P_argv;
 
 extern void scan1(char *s, short p, short *n);
 /* Read an integer at position p of s */
-extern boolean match(char *s1, char *s2);
+extern boolean startsWith(char *s1, char *s2);
 /* True if s1 starts with s2 */
 extern short pos1(char c, char *s);
 extern short posnot(char c, char *s);
@@ -52,7 +53,7 @@ extern void insertchar(char c, char *s, short p);
 extern char *substr_(char *Result, char *s, short start, short count);
 extern void get_num(char *line, short *k);
 extern void get_nums(char *line, short *k1, short *k2);
-extern void uppercase(char *s);
+extern void toUpper(char *s);
 extern void delete1(char *s, short p);
 extern void predelete(char *s, short l);
 extern void shorten(char *s, short new_length);
