@@ -9,8 +9,11 @@
 #include "globals.h"
 
 
+char double_comment[3] = "%%";
 char durations[ndurs + 1] = "90248136";
 char terminators[256] = ".x";
+char has_duration[9] = "abcdefgr";
+char solfa_names[8] = "drmfslt";
 char choice = ' ';
 short verbose = 0;
 boolean ignore = false, dochords = true, dotext = true, dolyrics = true,
@@ -28,6 +31,18 @@ boolean ignore_input = false;
 #endif
 
 
+boolean isNoteOrRest(char *w)
+{
+  return (pos1(w[0], has_duration) > 0);
+}
+
+
+boolean isPause(char *note)
+{
+  return (startsWith(note, pause));
+}
+
+
 void cancel(short *num, short *denom, short lowest)
 {
   while (((*num) & 1) == 0 && *denom > lowest) {
@@ -97,29 +112,6 @@ boolean endsWith(char *s1_, char *s2)
 }
 
 
-void setMeter(char *line_)
-{
-  char line[256];
-  char meter[256];
-
-  strcpy(line, line_);
-  GetNextWord(meter, line, blank, dummy);
-  if (!strcmp(meter, "C/")) {
-    meternum = 2;
-    meterdenom = 2;
-    pmdenom = 5;
-    pmnum = 0;
-  } else if (!strcmp(meter, "C")) {
-    meternum = 4;
-    meterdenom = 4;
-    pmdenom = 6;
-    pmnum = 0;
-  } else
-    readMeter(meter, &meternum, &meterdenom, &pmnum, &pmdenom);
-  setDefaultDuration(meterdenom);
-}
-
-
 static void onumber(char *s, short *j, short *n1)
 {
   if (s[*j - 1] == 'o')
@@ -196,7 +188,7 @@ void trim(char *s)
 }
 
 
-short whereInParagraph(short l)
+static short whereInParagraph(short l)
 {
   short Result = 0;
   short j, FORLIM;
@@ -380,10 +372,14 @@ short PMXinstr(short stave)
 }
 
 
-void setDefaultDuration(short meterdenom)
+static void setDefaultDuration(short meterdenom)
 {
   switch (meterdenom) {
 
+  case 1:
+    default_duration = '0';
+    break;
+
   case 2:
     default_duration = '2';
     break;
@@ -411,6 +407,29 @@ void setDefaultDuration(short meterdenom)
 }
 
 
+void setMeter(char *line_)
+{
+  char line[256];
+  char meter[256];
+
+  strcpy(line, line_);
+  GetNextWord(meter, line, blank, dummy);
+  if (!strcmp(meter, "C/")) {
+    meternum = 2;
+    meterdenom = 2;
+    pmdenom = 5;
+    pmnum = 0;
+  } else if (!strcmp(meter, "C")) {
+    meternum = 4;
+    meterdenom = 4;
+    pmdenom = 6;
+    pmnum = 0;
+  } else
+    readMeter(meter, &meternum, &meterdenom, &pmnum, &pmdenom);
+  setDefaultDuration(meterdenom);
+}
+
+
 
 
 /* End. */
