@@ -9,10 +9,6 @@
 #include "lyrics.h"
 
 
-#ifndef GLOBALS_H
-#include "globals.h"
-#endif
-
 #ifndef STRINGS_H
 
 #endif
@@ -38,6 +34,10 @@
 #define inhibit_slur_melisma  '{'
 
 
+typedef char other_index;
+
+typedef char other_index0;
+
 typedef char melismatype[256];
 
 typedef enum {
@@ -85,11 +85,12 @@ static lyrinfotype lyrinfo[maxvoices];
 void lyricsParagraph(void)
 {
   char first[256], w[256];
-  short i, l, line;
-  short nother = 0;
-  char other_[10][256];
+  paragraph_index0 l, line;
+  other_index0 i;
+  other_index0 nother = 0;
+  char other_[10][41];
   char STR1[256], STR3[256];
-  short FORLIM;
+  paragraph_index0 FORLIM;
   char STR4[256];
   char STR5[256];
 
@@ -108,6 +109,8 @@ void lyricsParagraph(void)
       sprintf(w, "{%s", strcpy(STR1, w));
     nother++;
     GetNextWord(other_[nother-1], w, dummy, '}');
+/* p2c: lyrics.pas, line 71:
+ * Note: Possible string truncation in assignment [145] */
   }
   if (verbose > 0) {
     printf("---- Paragraph %d starting at line %d has lyrics headed %s",
@@ -155,7 +158,7 @@ void lyricsParagraph(void)
 }
 
 
-static char *songraise(char *Result, short voice)
+static char *songraise(char *Result, voice_index voice)
 {
   char s[256];
   lyrtagtype *WITH;
@@ -180,7 +183,7 @@ static char *songraise(char *Result, short voice)
 }
 
 
-char *lyricsReport(char *Result, short voice)
+char *lyricsReport(char *Result, voice_index voice)
 {
   char l[256];
   lyrtagtype *WITH;
@@ -207,9 +210,11 @@ char *lyricsReport(char *Result, short voice)
 void initLyrics(void)
 {
   /* at the start only */
-  short stave, voice, FORLIM;
+  stave_index stave;
+  voice_index voice, FORLIM;
   lyrinfotype *WITH;
   lyrtagtype *WITH1;
+  stave_index FORLIM1;
 
   FORLIM = nvoices;
   for (voice = 0; voice <= FORLIM - 1; voice++) {
@@ -223,13 +228,13 @@ void initLyrics(void)
     WITH1->new_assign = asbefore;
     WITH1->initialized = virgin;
   }
-  FORLIM = nstaves;
-  for (stave = 0; stave <= FORLIM - 1; stave++)
+  FORLIM1 = nstaves;
+  for (stave = 0; stave <= FORLIM1 - 1; stave++)
     oldlyrmodealter[stave] = false;
 }
 
 
-static void registerLyrics(short voice, char *w)
+static void registerLyrics(voice_index voice, char *w)
 {
   lyrtagtype *WITH;
 
@@ -254,7 +259,7 @@ static void registerLyrics(short voice, char *w)
 }
 
 
-void extractLyrtag(short voice, char *note)
+void extractLyrtag(voice_index voice, char *note)
 {
   /* inline lyrics change */
   lyrtagtype *WITH;
@@ -278,7 +283,7 @@ void extractLyrtag(short voice, char *note)
 void clearTags(void)
 {
   /* at start of paragraph analyis */
-  short voice, FORLIM;
+  voice_index voice, FORLIM;
   lyrtagtype *WITH;
 
   memcpy(oldtag, tag, maxvoices * sizeof(lyrtagtype));
@@ -295,7 +300,7 @@ void clearTags(void)
 #define maxlyrlen       (PMXlinelength - 15)
 
 
-static void convertlyrics(char *lyn, short voice, auxtype mx)
+static void convertlyrics(char *lyn, voice_index voice, auxtype mx)
 {
   static char setlyr[256] = "%%\\\\\\setlyrics";
   char btag[256], thistag[256], w[256];
@@ -336,11 +341,11 @@ static void convertlyrics(char *lyn, short voice, auxtype mx)
 #undef maxlyrlen
 
 
-void maybeLyrics(short voice, short parline, char *w_)
+void maybeLyrics(voice_index voice, paragraph_index parline, char *w_)
 {
   /* during paragraph analysis, parline had L:, already stripped */
   char w[256];
-  short k;
+  voice_index0 k;
 
   /**  Labelled lyrics line -- */
   strcpy(w, w_);
@@ -367,8 +372,11 @@ void maybeLyrics(short voice, short parline, char *w_)
 void reviseLyrics(void)
 {
   /* after paragraph analysis */
-  short voice, stave, FORLIM;
+  voice_index voice;
+  stave_index stave;
+  voice_index FORLIM;
   lyrtagtype *WITH;
+  stave_index FORLIM1;
 
   FORLIM = nvoices;
   for (voice = 0; voice <= FORLIM - 1; voice++) {
@@ -385,8 +393,8 @@ void reviseLyrics(void)
     strcpy(oldtag[voice].tags, WITH->tags);
     oldtag[voice].lyrsource = WITH->lyrsource;
   }
-  FORLIM = nstaves;
-  for (stave = 0; stave <= FORLIM - 1; stave++) {
+  FORLIM1 = nstaves;
+  for (stave = 0; stave <= FORLIM1 - 1; stave++) {
     WITH = &tag[first_on_stave[stave] - 1];
     lyrmodealter[stave] = (number_on_stave[stave] > 1 &&
 			   WITH->has_lyrics == haslyr &&
@@ -395,11 +403,11 @@ void reviseLyrics(void)
 }
 
 
-void assignLyrics(short stave, char *lyrassign)
+void assignLyrics(stave_index stave, char *lyrassign)
 {
   /* at start of new block */
   char atag[256], instr[256], l[256];
-  short v1, v2, voice;
+  voice_index v1, v2, voice;
   char STR1[256];
   lyrtagtype *WITH;
   lyrinfotype *WITH1;
@@ -450,7 +458,7 @@ void assignLyrics(short stave, char *lyrassign)
 }
 
 
-void lyricsAdjust(short voice, char *note)
+void lyricsAdjust(voice_index voice, char *note)
 {
   /* inline at-word */
   short adj;
@@ -564,7 +572,7 @@ static boolean OpenMelisma(char *s)
 
 /* static variables for getSyllable: */
 struct LOC_getSyllable {
-  short voice;
+  voice_index voice;
   char pre[256];
   boolean hanging_slur;
 } ;
@@ -637,7 +645,7 @@ static char start(boolean no_slur_melisma)
     return slur_melisma;
 }
 
-static void startSlurMelisma(short voice, struct LOC_getSyllable *LINK)
+static void startSlurMelisma(voice_index voice, struct LOC_getSyllable *LINK)
 {
   char slurs[256];
   char STR1[256];
@@ -649,7 +657,7 @@ static void startSlurMelisma(short voice, struct LOC_getSyllable *LINK)
   startMelisma(slurs, LINK);
 }
 
-static void startBeamMelisma(short voice, struct LOC_getSyllable *LINK)
+static void startBeamMelisma(voice_index voice, struct LOC_getSyllable *LINK)
 {
   char STR1[256];
 
@@ -663,7 +671,7 @@ static void startBeamMelisma(short voice, struct LOC_getSyllable *LINK)
 }
 
 
-void getSyllable(short voice_, char *pretex)
+void getSyllable(voice_index voice_, char *pretex)
 {
   struct LOC_getSyllable V;
 
