@@ -9,10 +9,6 @@
 #include "mtx.h"
 
 
-#ifndef GLOBALS_H
-#include "globals.h"
-#endif
-
 #ifndef MTXLINE_H
 #include "mtxline.h"
 #endif
@@ -25,45 +21,24 @@
 #include "status.h"
 #endif
 
+#ifndef NOTES_H
+#include "notes.h"
+#endif
 
-#define dot             '.'
-#define comma           ','
-#define dotcode         'd'
 
 #define flagged         "8136"
 
 #define crotchet        16
 
-#define has_duration    "abcdefgr"
-#define note_names      "abcdefg"
-
-#define rest_           'r'
 #define tex_escape      '\\'
-#define unspecified     '5'   /* Not a valid duration */
 
 
 typedef boolean sticky['z' + 1 - 'a'];
 
 
-static short count64['9' + 1 - '0'] = {
-  64, 4, 32, 2, 16, 0, 1, 0, 8, 128
-};
-
 static sticky note_attrib[maxvoices], rest_attrib[maxvoices];
 
 
-boolean isNoteOrRest(char *w)
-{
-  return (pos1(w[0], has_duration) > 0);
-}
-
-
-boolean isPause(char *note)
-{
-  return (startsWith(note, pause));
-}
-
-
 static short logTwo(short denom)
 {
   short l = 0;
@@ -127,140 +102,6 @@ char *rests(char *Result, short len, short meterdenom, boolean blind)
 }
 
 
-static void extractDurationCode(char *note, char *code)
-{
-  short i = 2;
-  short l;
-  char term[256];
-
-  *code = unspecified;
-  l = strlen(note);
-  strcpy(term, terminators);
-  if (note[0] == 'r')
-    strcat(term, "+-");
-  if (l < 2 || !isNoteOrRest(note))
-    return;
-  while (i <= l) {
-    if (pos1(note[i-1], durations) > 0) {
-      *code = note[i-1];
-      delete1(note, i);
-      return;
-    }
-    if (pos1(note[i-1], term) > 0)
-      return;
-    i++;
-  }
-}
-
-
-static char durationCode(char *note_)
-{
-  char note[256];
-  char code;
-
-  strcpy(note, note_);
-  extractDurationCode(note, &code);
-  return code;
-}
-
-
-static char half(char dur)
-{
-  char Result;
-  short k;
-  char STR1[20];
-  char STR2[24];
-
-  k = pos1(dur, durations);
-  Result = dur;
-  if (k == 0) {
-    sprintf(STR1, "Invalid duration %c", dur);
-    error(STR1, print);
-    return Result;
-  }
-  if (k <= ndurs)
-    return (durations[k]);
-  sprintf(STR2, "%c is too short to halve", dur);
-  error(STR2, print);
-  return Result;
-}
-
-
-typedef enum {
-  solitary, three_one, two_one
-} grouptype;
-
-
-/* static variables for expand: */
-struct LOC_expand {
-  char *note, *xnote;
-  char *dur;
-  char note1[256];
-  grouptype group;
-} ;
-
-static void dotme(struct LOC_expand *LINK)
-{
-  char STR1[256];
-
-  if (split_dots)
-    *LINK->dur = half(*LINK->dur);
-  if (LINK->group == two_one)
-    GetNextWord(LINK->note1, LINK->note, comma, dummy);
-  else
-    sprintf(LINK->note1, "%s%c",
-	    GetNextWord(STR1, LINK->note, dot, dummy), dotcode);
-  addDuration(LINK->note1, LINK->dur);
-  *LINK->dur = half(*LINK->dur);
-  addDuration(LINK->note, LINK->dur);
-  strcpy(LINK->xnote, LINK->note);
-  strcpy(LINK->note, LINK->note1);
-}
-
-
-/* Expand dot groups */
-static void expand(char *note_, char *xnote_, char dur1, char *dur_)
-{
-  struct LOC_expand V;
-  short k;
-  char dur2;
-
-  V.note = note_;
-  V.xnote = xnote_;
-  V.dur = dur_;
-  *V.xnote = '\0';
-  if (*V.note == '\0' || !isNoteOrRest(V.note) || isPause(V.note))
-    return;
-  extractDurationCode(V.note, &dur2);
-  if (dur2 == unspecified)
-    *V.dur = dur1;
-  else
-    *V.dur = dur2;
-  k = pos1(dot, V.note);
-  if (k > 0)
-    V.group = three_one;
-  else {
-    k = pos1(comma, V.note);
-    if (k > 0)
-      V.group = two_one;
-    else
-      V.group = solitary;
-  }
-  if (k == strlen(V.note))
-    error("Note may not end in dot or comma", print);
-  else if (V.group != solitary) {
-    if (tonic_solfa)
-      translateSolfa(&V.note[k]);
-    if (pos1(V.note[k], note_names) == 0)
-      error("Dot or comma must be followed by notename", print);
-  }
-  if (V.group == solitary)
-    insertchar(*V.dur, V.note, 2);
-  else
-    dotme(&V);
-}
-
-
 static char *attribs(char *Result, char *note)
 {
   char a[256];
@@ -312,13 +153,7 @@ static void checkSticky(char *note, boolean *attrib)
 }
 
 
-void extendRest(char *rest, short voice)
-{
-  SetDuration(rest, voice);
-}
-
-
-void checkOctave(char *note, short voice)
+void checkOctave(voice_index voice, char *note)
 {
   short i;
 
@@ -343,7 +178,7 @@ void checkOctave(char *note, short voice)
 }
 
 
-void markDebeamed(char *note, short voice)
+void markDebeamed(voice_index voice, char *note)
 {
   if (isVocal(voice) && afterSlur(voice) == 0 && unbeam_if_vocal &&
       pos1(duration(voice), flagged) > 0)
@@ -351,50 +186,6 @@ void markDebeamed(char *note, short voice)
 }
 
 
-short l64(char *note)
-{
-  return (count64[durationCode(note) - '0']);
-}
-
-
-short noteLength(char *note, short voice)
-{
-  short Result = 0, i = 2;
-  short l, nl, tnl;
-  char dur1, dur2;
-  char STR1[256];
-
-  dur1 = duration(voice);
-  if (*note == '\0')
-    return Result;
-  if (isPause(note))
-    return full_bar;
-  if (!isNoteOrRest(note))
-    return Result;
-  dur2 = durationCode(note);
-  if (dur2 != unspecified)
-    dur1 = dur2;
-  nl = count64[dur1 - '0'];
-  tnl = nl;
-  l = strlen(note);
-  while (i <= l) {
-    sprintf(STR1, "%c", dotcode);
-    if (pos1(note[i-1], STR1) > 0) {
-      nl /= 2;
-      tnl += nl;
-    } else if (pos1(note[i-1], terminators) > 0)
-      i = l;
-    i++;
-  }
-  if (pos1(dot, note) > 0)
-    tnl += tnl;
-  else if (pos1(comma, note) > 0)
-    tnl += tnl / 2;
-  return tnl;
-/* p2c: mtx.pas: Note: Deleting unreachable code [255] */
-}
-
-
 static short barLength(char *meter)
 {
   short n1, n2, pn1, pn2;
@@ -404,25 +195,28 @@ static short barLength(char *meter)
 }
 
 
-static void checkMultiBarRest(char *rest)
+static boolean isMultiBarRest(char *rest_)
 {
-  if (strlen(rest) < 3)
-    return;
-  if (rest[1] != 'm')
-    return;
+  boolean Result;
+
+/* p2c: mtx.pas: Note: Eliminated unused assignment statement [338] */
+  if (strlen(rest_) < 3)
+    return false;
+  if (rest_[1] != 'm')
+    return false;
   if (multi_bar_rest)
     error("Only one multibar rest allowed per line", print);
   multi_bar_rest = true;
+  return true;
 }
 
 
 /* static variables for scanMusic: */
 struct LOC_scanMusic {
-  short voice;
+  voice_index voice;
   char note[256];
   boolean beam_next;
-  short bar, bar_length, dotme, i, l, nl, ngrace, nmulti;
-  char dur1, dur2;
+  short bar, bar_length, count, dotme, l, nl, ngrace, nmulti;
 } ;
 
 /* static variables for countIt: */
@@ -440,8 +234,6 @@ static void incbar(short nl, struct LOC_countIt *LINK)
 static void countIt(struct LOC_scanMusic *LINK)
 {
   struct LOC_countIt V;
-  boolean dotadd;
-  char STR1[256];
 
   V.LINK = LINK;
   if (LINK->ngrace > 0) {
@@ -452,42 +244,30 @@ static void countIt(struct LOC_scanMusic *LINK)
     LINK->nmulti--;
     return;
   }
-  LINK->dur2 = durationCode(LINK->note);
-  if (LINK->dur2 != unspecified)
-    LINK->dur1 = LINK->dur2;
-  LINK->nl = count64[LINK->dur1 - '0'];
-  incbar(LINK->nl, &V);
-  if (pos1(comma, LINK->note) > 0)
-    incbar(LINK->nl / 2, &V);
-  else {
-    if (pos1(dot, LINK->note) > 0)
-      LINK->dotme = 2;
-    else
-      LINK->dotme = 1;
-    if (!split_dots && LINK->dotme == 2) {
-      LINK->dotme = 1;
-      incbar(LINK->nl, &V);
-    }
-    LINK->l = strlen(LINK->note);
-    LINK->i = 2;
-    dotadd = false;
-    while (LINK->i <= LINK->l) {
-      sprintf(STR1, "%c", dotcode);
-      if (pos1(LINK->note[LINK->i-1], STR1) > 0) {
-	LINK->nl /= 2;
-	incbar(LINK->nl, &V);
-	dotadd = true;
-      } else if (pos1(LINK->note[LINK->i-1], terminators) > 0)
-	LINK->i = LINK->l;
-      LINK->i++;
-    }
-  }
-  if (!dotadd &&
-      (LINK->note[0] != rest_ && note_attrib[LINK->voice-1]['d' - 'a'] ||
-       LINK->note[0] == rest_ && rest_attrib[LINK->voice-1]['d' - 'a'])) {
-    LINK->nl /= 2;
-    incbar(LINK->nl, &V);
-  }
+  /* dur2:=durationCode(note);
+    if dur2<>unspecified then dur1:=dur2;
+    nl:=count64[dur1];  incbar(nl);
+    if pos1(comma,note)>0 then incbar(nl div 2)
+    else begin
+      if pos1(dot,note)>0 then dotme:=2 else dotme:=1;
+      if not split_dots and (dotme=2) then
+      begin dotme:=1; incbar(nl); end;
+      l := length(note);  i:=2;  dotadd:=false;
+      while i <= l do
+      begin  if pos1(note[i],dotcode)>0 then
+        begin  nl:=nl div 2;  incbar(nl);  dotadd:=true; end
+        else if pos1(note[i],terminators)>0 then i:=l;
+        inc(i);
+      end;
+    end; */
+  if (LINK->count % 3 != 0 &&
+      (LINK->note[0] != rest && note_attrib[LINK->voice-1]['d' - 'a'] ||
+       LINK->note[0] == rest && rest_attrib[LINK->voice-1]['d' - 'a']))
+    LINK->count += LINK->count / 2;
+/* p2c: mtx.pas, line 151:
+ * Note: Using % for possibly-negative arguments [317] */
+  incbar(LINK->count, &V);
+  /*        begin  nl:=nl div 2;  incbar(nl);  end;  */
   /* ------------ did you forget duration under beam? ------------ */
   if (LINK->beam_next && LINK->nl / LINK->dotme >= crotchet)
     warning("Note under beam has length 1/4 or more", print);
@@ -522,12 +302,12 @@ static void maybeGroup(struct LOC_scanMusic *LINK)
 }
 
 
-void scanMusic(short voice_, short *l1)
+void scanMusic(voice_index voice_, short *left_over)
 {
   struct LOC_scanMusic V;
   char buf[256], enote[256], xnote[256];
   boolean has_next = false, done = false;
-  char lastdur;
+  char dur1, lastdur;
   music_word nscan;
   char STR1[256];
 
@@ -535,28 +315,29 @@ void scanMusic(short voice_, short *l1)
   if (extended_dots)
     strcpy(terminators, "d.x");
   resetInfo(V.voice, buf);
-  *l1 = 0;
+  *left_over = 0;
   V.bar = full_bar;
   V.bar_length = 0;
   V.ngrace = 0;
   V.nmulti = 0;
   if (meternum == 0)
     V.bar = 32000;
-  V.dur1 = duration(V.voice);
-  lastdur = V.dur1;
+  dur1 = duration(V.voice);
+  lastdur = dur1;
   V.beam_next = false;
   do {
     getNextMusWord(buf, V.note, &nscan);
+    V.count = 0;
+    /*    if isNoteOrRest(note) and not (isPause(note) or isMultibarRest(note))
+          then note:=toStandard(note); */
     if (nscan == mword) {
       if (V.bar_length > 0)
 	error3(V.voice, "Meter change only allowed at start of bar");
       else
 	V.bar = barLength(V.note);
-    }
-    if (nscan == rword) {
-      checkMultiBarRest(V.note);
-      if (!(isPause(V.note) || multi_bar_rest)) {
-	expand(V.note, xnote, V.dur1, &lastdur);
+    } else if (nscan == rword) {
+      if (!(isPause(V.note) || isMultiBarRest(V.note))) {
+	parseNote(V.note, xnote, dur1, &lastdur, &V.count);
 	checkSticky(V.note, rest_attrib[V.voice-1]);
       }
     }
@@ -565,7 +346,7 @@ void scanMusic(short voice_, short *l1)
     strcpy(enote, V.note);
     if (nscan == abcdefg) {
       if (!multi_bar_rest && V.ngrace + V.nmulti == 0) {
-	expand(enote, xnote, V.dur1, &lastdur);
+	parseNote(enote, xnote, dur1, &lastdur, &V.count);
 	if (*xnote != '\0') {
 	  checkSticky(enote, note_attrib[V.voice-1]);
 	  appendToLine(V.voice, enote);
@@ -587,9 +368,9 @@ void scanMusic(short voice_, short *l1)
       else if (numberOfBars(V.voice) == 0 && V.bar_length < V.bar) {
 	if (has_next)
 	  has_next = false;   /*Should check whether pickups are equal*/
-	else if (*l1 > 0)
+	else if (*left_over > 0)
 	  error3(V.voice, "Bar is too short");
-	*l1 = V.bar_length;
+	*left_over = V.bar_length;
 	V.bar_length = 0;
       }
     }
@@ -607,23 +388,23 @@ void scanMusic(short voice_, short *l1)
       else
 	maybeGroup(&V);
     }
+    dur1 = lastdur;
     if (V.bar_length >= V.bar && V.ngrace + V.nmulti == 0) {
       barForward(V.voice, V.bar_length / V.bar);
       V.bar_length %= V.bar;
-/* p2c: mtx.pas, line 351:
+/* p2c: mtx.pas, line 238:
  * Note: Using % for possibly-negative arguments [317] */
     }
   } while (!done);
   setExtraLength(V.voice, V.bar_length);
-  if (V.dur1 != lastdur)
-    warning("Explicit duration probably needed in next paragraph", print);
+  resetDuration(V.voice, dur1);
   regroup(V.voice);
 }
 
 
 void initMTX(void)
 {
-  short i;
+  voice_index i;
   char j;
 
   for (i = 0; i <= maxvoices - 1; i++) {
