@@ -9,10 +9,6 @@
 #include "preamble.h"
 
 
-#ifndef GLOBALS_H
-#include "globals.h"
-#endif
-
 #ifndef MTXLINE_H
 #include "mtxline.h"
 #endif
@@ -26,6 +22,14 @@
 #endif
 
 
+#define blank_          ' '
+#define colon_          ':'
+#define semicolon       ';'
+#define comma           ','
+
+#define max_styles      24
+
+
 typedef enum {
   none, title, composer, pmx, options, msize, bars, shortnote, style, sharps,
   flats, meter, space, pages, systems, name, indent, poet, part, only, start
@@ -35,17 +39,17 @@ typedef enum {
   unknown, colon_line, command_line, comment_line, plain_line
 } line_type;
 
+typedef char style_index;
+
+typedef char style_index0;
+
 
 #define c1              title
 #define cn              start
 
-#define blank_          ' '
-#define colon_          ':'
-#define semicolon       ';'
-#define comma           ','
-
-#define max_styles      24
 
+static short known_styles = 12;
+static boolean warn_redefine = false;
 
 static char commands[21][17] = {
   "NONE", "TITLE", "COMPOSER", "PMX", "OPTIONS", "SIZE", "BARS/LINE", "SHORT",
@@ -63,9 +67,6 @@ static boolean redefined[21] = {
   false, false, false, false, false, false, false, false, false, false
 };
 
-static short known_styles = 12;
-static boolean warn_redefine = false;
-
 /** Known styles */
 
 static char known_style[max_styles][256] = {
@@ -83,10 +84,10 @@ static char known_style[max_styles][256] = {
   "", "", "", "", "", "", "", "", ""
 };
 
-static short old_known_styles;
+static style_index old_known_styles;
 static boolean style_used[max_styles];
 static boolean omit_line[lines_in_paragraph];
-static short orig_style_line[max_styles];
+static style_index0 orig_style_line[max_styles];
 static short preamble_line[21];
 
 static short nclefs, n_pages, n_systems, n_sharps, ngroups;
@@ -100,7 +101,7 @@ static boolean style_applied, style_supplied;
 
 /* ------------------ Styles ------------------ */
 
-static short voiceCount(char *s_)
+static voice_index0 voiceCount(char *s_)
 {
   char s[256];
   short i, l;
@@ -115,11 +116,11 @@ static short voiceCount(char *s_)
 }
 
 
-static short findStyle(char *s_)
+static style_index0 findStyle(char *s_)
 {
-  short Result = 0;
+  style_index0 Result = 0;
   char s[256];
-  short i = 0;
+  style_index0 i = 0;
 
   strcpy(s, s_);
   sprintf(s + strlen(s), "%c", colon_);
@@ -134,7 +135,7 @@ static short findStyle(char *s_)
 
 static void addStyle(char *S)
 {
-  short sn;
+  style_index0 sn;
   char STR1[256];
 
   sn = findStyle(NextWord(STR1, S, colon_, dummy));
@@ -154,7 +155,7 @@ static void readStyles(void)
 {
   boolean eofstyle;
   char S[256];
-  short l = 0;
+  style_index0 l = 0;
   char *TEMP;
 
   if (styleFileFound())
@@ -176,12 +177,12 @@ static void readStyles(void)
 }
 
 
-static void applyStyle(char *s_, char *stylename, short first_inst,
-		       short first_stave)
+static void applyStyle(char *s_, char *stylename, stave_index first_inst,
+		       stave_index first_stave)
 {
   char s[256];
   char clef[256], subline[256], subcommand[256];
-  short i, last_inst, last_stave;
+  stave_index0 i, last_inst, last_stave;
   boolean continuo = false, toosoon = false, vocal = false;
   char STR2[256];
 
@@ -245,7 +246,7 @@ static void applyStyle(char *s_, char *stylename, short first_inst,
     error("Number of clefs does not match number of voices", print);
   if (first_stave == last_stave || continuo) {
     strcpy(instr_name[first_stave-1], stylename);
-/* p2c: preamble.pas, line 178:
+/* p2c: preamble.pas, line 182:
  * Note: Possible string truncation in assignment [145] */
   } else {
     for (i = first_stave - 1; i <= last_stave - 1; i++)
@@ -304,7 +305,7 @@ static void wipeCommands(void)
 }
 
 
-boolean omitLine(short line)
+boolean omitLine(paragraph_index line)
 {
   if (line == 0)
     return true;
@@ -323,7 +324,7 @@ static void setName(void)
   FORLIM = ninstr;
   for (i = 0; i <= FORLIM - 1; i++) {
     GetNextWord(instr_name[i], cline[(long)name], blank_, dummy);
-/* p2c: preamble.pas, line 219:
+/* p2c: preamble.pas, line 223:
  * Note: Possible string truncation in assignment [145] */
   }
 }
@@ -338,7 +339,7 @@ static void setIndent(void)
 
 static void checkLabel(char *w)
 {
-  short j, FORLIM;
+  voice_index j, FORLIM;
   char STR1[256], STR2[256];
 
   FORLIM = nvoices;
@@ -388,7 +389,7 @@ static void setVoices(char *line)
 	    strcpy(voice_label[nvoices-1], w);
 	    if (*instr_name[nstaves-1] == '\0') {
 	      strcpy(instr_name[nstaves-1], w);
-/* p2c: preamble.pas, line 255:
+/* p2c: preamble.pas, line 259:
  * Note: Possible string truncation in assignment [145] */
 	    }
 	    setStavePos(nvoices, nstaves, k);
@@ -402,7 +403,7 @@ static void setVoices(char *line)
       if (k == 2) {
 	sprintf(instr_name[nstaves-1], "\\vbox{\\hbox{%s}\\hbox{%s}}",
 		voice_label[nvoices-2], voice_label[nvoices-1]);
-/* p2c: preamble.pas, line 262:
+/* p2c: preamble.pas, line 266:
  * Note: Possible string truncation in assignment [145] */
       }
       number_on_stave[nstaves-1] = k;
@@ -434,7 +435,7 @@ static void setClefs(char *line_)
 static void setSize(char *line_)
 {
   char line[256];
-  short i = 0;
+  stave_index0 i = 0;
   char word[256];
 
   strcpy(line, line_);
@@ -663,7 +664,7 @@ void preambleDefaults(void)
 }
 
 
-static void preambleGuess(short maybe_voices)
+static void preambleGuess(voice_index maybe_voices)
 {
   switch (maybe_voices) {
 
@@ -710,7 +711,7 @@ static void preambleGuess(short maybe_voices)
 
 void nonMusic(void)
 {
-  short i, FORLIM;
+  paragraph_index i, FORLIM;
 
   FORLIM = para_len;
   for (i = 0; i <= FORLIM - 1; i++)
@@ -735,10 +736,10 @@ boolean thisCase(void)
 
 void augmentPreamble(boolean control_para)
 {
-  short i;
+  paragraph_index i;
   line_type l;
   short s[5];
-  short FORLIM;
+  paragraph_index FORLIM;
 
   if (!thisCase())
     return;
@@ -763,9 +764,9 @@ void augmentPreamble(boolean control_para)
 
 void doPreamble(void)
 {
-  short i;
-  short maybe_voices = 0;
-  short FORLIM;
+  paragraph_index i;
+  voice_index0 maybe_voices = 0;
+  paragraph_index FORLIM;
 
   if (style_supplied)  /*augmentPreamble(not known);*/
     return;
@@ -785,7 +786,7 @@ void doPreamble(void)
 
 void respace(void)
 {
-  short i, j;
+  stave_index i, j;
   char STR1[256];
   char STR2[256], STR3[256];
 
@@ -865,18 +866,18 @@ static short clefno(char cl)
 
 static void doTenorClefs(void)
 {
-  short i;
+  voice_index i;
   char c;
-  short FORLIM;
+  voice_index FORLIM;
   char STR1[256];
   char STR3[256];
 
   FORLIM = nclefs;
   for (i = 1; i <= FORLIM; i++) {
-    c = clef[nclefs - i];
+    c = clef[i-1];
     if (c == '8' || c == 't') {
       sprintf(STR3, "\\\\settrebleclefsymbol{%s}\\treblelowoct\\",
-	      toString(STR1, i));
+	      toString(STR1, PMXinstr(i)));
       putLine(STR3);
     }
   }
@@ -1028,18 +1029,15 @@ void doPMXpreamble(void)
   }
   if (*pmx_line != '\0')
     putLine(pmx_line);
-  FORLIM = first_par_PMX_len;
-  for (i = 0; i <= FORLIM - 1; i++)
-    putLine(first_par_PMX[i]);
   doTenorClefs();
   wipeCommands();
 }
 
 
-char *startString(char *Result, short voice)
+char *startString(char *Result, voice_index0 voice)
 {
   char s[256], w[256];
-  short j;
+  voice_index j;
 
   strcpy(s, start_line);
   for (j = 1; j <= voice; j++)
