@@ -9,14 +9,14 @@
 
 #endif
 
-#ifndef PREAMBLE_H
-#include "preamble.h"
-#endif
-
 #ifndef GLOBALS_H
 #include "globals.h"
 #endif
 
+#ifndef PREAMBLE_H
+#include "preamble.h"
+#endif
+
 #ifndef LYRICS_H
 #include "lyrics.h"
 #endif
@@ -48,25 +48,14 @@
 
 /** M-Tx preprocessor to PMX     Dirk Laurie */
 
-#define version         "0.50a"
-#define version_date    "<8 October 1998>"
+#define version         "0.52"
+#define version_date    "<29 October 1998>"
 
 /** To do next:
    If upper voice is alone on stave, don't use lyralter
 {* Current improvements:
-   Case:
-   Start:
-   Poet:
-   Part:
-   < with a number
-   15 instruments/staves
-   suspend/resume
-   Only:
-   rpb, rp+3, rp always visible
-   broken slurs
-   G8 tenor clef
+   .. shortcut
 {* Current bugs:
-   Workaround for PMX 1.3.8 'rD' bug
 {* Old bugs:
    Does not check PMX syntax
 {* Weaknesses that may later cause bugs:
@@ -82,9 +71,6 @@
 
 #define chord_flat      't'
 #define chord_left      'l'
-
-#define fermataDown     "oF"
-
 #define lyrics_adj      '@'
 
 #define blind           true
@@ -109,25 +95,25 @@ static void writeRepeat(char *bar)
   *repcode = '\0';
   if (!strcmp(bar, "||"))
     strcpy(repcode, "Rd");
-  else if (!strcmp(bar, "|]") && !last_bar) {
+  else if (!strcmp(bar, "|]"))
     strcpy(repcode, "RD");
-    /*    PMX 1.3.8 bug: RD not recognized at end of piece */
-  } else if (!strcmp(bar, "|:"))
+  else if (!strcmp(bar, "|:"))
     strcpy(repcode, "Rl");
   else if (!strcmp(bar, ":|:"))
     strcpy(repcode, "Rlr");
   else if (!strcmp(bar, ":|"))
     strcpy(repcode, "Rr");
+  else if (last_bar && !strcmp(bar, "|"))
+    strcpy(repcode, "Rb");
   if (*repcode != '\0') {
     sprintf(STR1, " %s", repcode);
     putLine(STR1);
-  } else if (last_bar && !strcmp(bar, "|"))
-    putLine(" \\\\\\let\\Endpiece=\\endpiece\\");
+  }
   *bar = '\0';
 }
 
 
-static void supplyRests(short voice)
+static void supplyRests(voice_index voice)
 {
   char STR2[4];
   char STR3[256];
@@ -174,7 +160,7 @@ static void countBars(char *note_)
 
 static void putMBRest(void)
 {
-  short i, FORLIM;
+  stave_index i, FORLIM;
   char STR1[256];
   char STR2[256], STR3[256];
 
@@ -195,74 +181,9 @@ static void putMBRest(void)
 }
 
 
-typedef enum {
-  no_pause, lower_pause, upper_pause, both_pauses
-} which_pauses;
-
-
-static which_pauses pauses[maxstaves];
-static short pause_height[maxvoices];
-
-
-static void clearPauses(void)
-{
-  short i, FORLIM;
-
-  FORLIM = nstaves;
-  for (i = 0; i <= FORLIM - 1; i++)
-    pauses[i] = no_pause;
-  FORLIM = nvoices;
-  for (i = 1; i <= FORLIM; i++) {
-    if (upper(i) || i == companion(i))
-      pause_height[i-1] = 0;
-    else
-      pause_height[i-1] = -2;
-  }
-}
-
-
-static void putPauses(void)
-{
-  short stave, bottom, top;
-  boolean go = false;
-  which_pauses ps;
-  short FORLIM;
-  char STR1[256];
-  char STR2[256], STR3[256];
-
-  FORLIM = nstaves;
-  for (stave = 0; stave <= FORLIM - 1; stave++)
-    go = (go || pauses[stave] != no_pause);
-  if (!go)
-    return;
-  put("\\gdef\\atnextbar{\\znotes", putspace);
-  for (stave = nstaves; stave >= 1; stave--) {
-    top = first_on_stave[stave-1];
-    bottom = companion(top);
-    ps = pauses[stave-1];
-    if (ps == lower_pause || ps == both_pauses) {
-      sprintf(STR3, "\\Lrp{%s}", toString(STR1, pause_height[bottom-1]));
-      put(STR3, nospace);
-    }
-    if (ps == upper_pause || ps == both_pauses) {
-      sprintf(STR2, "\\Lrp{%s}", toString(STR1, pause_height[top-1]));
-      put(STR2, nospace);
-    }
-    if (stave > 1) {
-      if (instr[stave-1] == instr[stave-2])
-	put("|", nospace);
-      else
-	put("&", nospace);
-    }
-  }
-  putLine("\\en}\\");
-  clearPauses();
-}
-
-
 /* static variables for processLine: */
 struct LOC_processLine {
-  short voice;
+  voice_index voice;
   char chords[256], note[256], pretex[256];
   short ngrace, nmulti;
   boolean last_was_tex, no_chords, no_uptext;
@@ -326,7 +247,8 @@ static void addChords(struct LOC_processLine *LINK)
   struct LOC_addChords V;
   char w[256];
   short j = 1;
-  short l, chord_line, mus_line;
+  short l, mus_line;
+  paragraph_index0 chord_line;
   boolean arpeggio;
   char STR1[256];
 
@@ -429,7 +351,6 @@ static char *processOther(char *Result, char *note_,
 
 static void lookahead(struct LOC_processLine *LINK)
 {
-  char STR1[256];
   char STR2[256];
   char STR3[256];
 
@@ -444,11 +365,6 @@ static void lookahead(struct LOC_processLine *LINK)
     case rbrac:
       incLastUnderBeam(LINK->voice);
       break;
-
-    case oword:
-      if (startsWith(nextMusicWord(STR1, LINK->voice), fermataDown))
-	error3(LINK->voice, "Use \"ofd\" for down fermata, not \"oF\"");
-      break;
     }
     sprintf(LINK->note + strlen(LINK->note), " %s",
 	    processOther(STR2, getMusicWord(STR3, LINK->voice), LINK));
@@ -473,12 +389,12 @@ static void processNote(struct LOC_processLine *LINK)
       LINK->nmulti--;
     }
   }
-  if (!in_group)
-    SetDuration(LINK->note, LINK->voice);
-  checkOctave(LINK->note, LINK->voice);
-  if (!in_group)
-    markDebeamed(LINK->note, LINK->voice);
+  checkOctave(LINK->voice, LINK->note);
   renewPitch(LINK->voice, LINK->note);
+  if (!in_group) {
+    resetDuration(LINK->voice, LINK->note[1]);
+    markDebeamed(LINK->voice, LINK->note);
+  }
   lookahead(LINK);
   getSyllable(LINK->voice, LINK->pretex);
   if (endsWith(LINK->note, "s~") || endsWith(LINK->note, "t~"))
@@ -488,37 +404,13 @@ static void processNote(struct LOC_processLine *LINK)
   addChords(LINK);
 }
 
-static void replacePause(char *note, struct LOC_processLine *LINK)
-{
-  short s;
-
-  s = voiceStave(LINK->voice);
-  predelete(note, 2);
-  if (strcmp(note, "b")) {
-    if (*note != '\0')
-      getNum(note, &pause_height[LINK->voice-1]);
-    if (upper(LINK->voice)) {
-      if (pauses[s-1] == no_pause)
-	pauses[s-1] = upper_pause;
-      else
-	pauses[s-1] = both_pauses;
-    } else if (pauses[s-1] == no_pause)
-      pauses[s-1] = lower_pause;
-    else
-      pauses[s-1] = both_pauses;
-  }
-  rests(note, full_bar, 1, blind);
-  if (LINK->voice == 1)
-    putPauses();
-}
-
 
 /* ---------------------------------------------------------------- */
 
-static void processLine(short voice_, short bar_no)
+static void processLine(voice_index voice_, short bar_no)
 {
   struct LOC_processLine V;
-  short par_line;
+  paragraph_index par_line;
   char STR1[256];
 
   V.voice = voice_;
@@ -534,20 +426,18 @@ static void processLine(short voice_, short bar_no)
     getMusicWord(V.note, V.voice);
     if (*V.note == '\0')
       return;
-    if (V.voice == 1 && !isPause(V.note) && pickup == 0)
-      putPauses();
     switch (thisNote(V.voice)) {
 
     case rword:
       if (multi_bar_rest) {
 	countBars(V.note);
 	strcpy(V.note, multibar);
-      } else if (isPause(V.note))
-	replacePause(V.note, &V);
-      else
-	extendRest(V.note, V.voice);
-      if (!no_uptext_for_rests)
-	addUptext(V.voice, &V.no_uptext, V.pretex);
+      } else {
+	if (!no_uptext_for_rests)
+	  addUptext(V.voice, &V.no_uptext, V.pretex);
+	if (!isPause(V.note))
+	  resetDuration(V.voice, V.note[1]);
+      }
       break;
 
     case abcdefg:
@@ -555,8 +445,6 @@ static void processLine(short voice_, short bar_no)
       break;
 
     case barword:
-      if (V.voice == 1 && !isPause(nextMusicWord(STR1, V.voice)) && pickup > 0)
-	putPauses();
       if (V.voice == nvoices) {
 	if (endOfBar(V.voice, bar_no))
 	  strcpy(repeat_sign, V.note);
@@ -589,7 +477,7 @@ static void processLine(short voice_, short bar_no)
 
 /* ------------------------------------------------------------------- */
 
-static void getMeterChange(short voice, char *new_meter)
+static void getMeterChange(voice_index voice, char *new_meter)
 {
   short pn1, pn2;
   char w[256], new_command[256];
@@ -614,9 +502,25 @@ struct LOC_musicParagraph {
   char new_meter[256];
 } ;
 
+static void putPMXlines(struct LOC_musicParagraph *LINK)
+{
+  paragraph_index i, FORLIM;
+
+  FORLIM = para_len;
+  for (i = 0; i <= FORLIM - 1; i++) {
+    if (startsWith(P[i], double_comment)) {
+      predelete(P[i], 2);
+      putLine(P[i]);
+      strcpy(P[i], "%");
+    }
+  }
+}
+
 static void processOneBar(struct LOC_musicParagraph *LINK)
 {
-  short m, cm, n1, n2, voice, cvoice;
+  paragraph_index0 m, cm;
+  short n1, n2;
+  voice_index voice, cvoice;
   boolean ignore_voice;
   boolean wrote_repeat = false;
   boolean alone;
@@ -632,8 +536,6 @@ static void processOneBar(struct LOC_musicParagraph *LINK)
     *repeat_sign = '\0';
   writeRepeat(repeat_sign);
   *LINK->new_meter = '\0';
-  clearPauses();
-  /* test for last_bar removed here */
   for (voice = nvoices; voice >= 1; voice--) {
     if (musicLineNo(voice) > 0) {
       gotoBar(voice, bar_of_line);
@@ -659,14 +561,10 @@ static void processOneBar(struct LOC_musicParagraph *LINK)
 	     m == 0 && cm == 0 && voice < cvoice);
     if (m > 0)
       processLine(voice, bar_of_line);
-    else {
-      if (voice == 1)
-	putPauses();
-      if (alone)
-	supplyRests(voice);
-      else
-	ignore_voice = true;
-    }
+    else if (alone)
+      supplyRests(voice);
+    else
+      ignore_voice = true;
     if (last_bar && *repeat_sign != '\0' && !wrote_repeat) {
       writeRepeat(repeat_sign);
       wrote_repeat = true;
@@ -696,12 +594,13 @@ static void putMeter(char *new_meter_word, struct LOC_musicParagraph *LINK)
 static void musicParagraph(void)
 {
   struct LOC_musicParagraph V;
-  short i, nvoice;
+  voice_index0 j, nvoice;
   char lyrassign[256];
   char STR1[256];
   char STR2[256];
   char STR3[256], STR4[256], STR5[256];
-  short FORLIM;
+  voice_index0 FORLIM;
+  short FORLIM1;
 
   paragraphSetup(&nvoice);
   if (nvoice == 0) {
@@ -739,26 +638,11 @@ static void musicParagraph(void)
     else
       putLine("1");
   }
-  FORLIM = para_len;
-  for (i = 0; i <= FORLIM - 1; i++)
-  {   /* ----- Wipe comments ------------------ */
-    if (P[i][0] == comment) {   /** Double comments are PMX lines   ------ */
-      if (P[i][1] == comment) {
-	predelete(P[i], 2);
-	if (pmx_preamble_done)
-	  putLine(P[i]);
-	else {
-	  first_par_PMX_len++;
-	  strcpy(first_par_PMX[first_par_PMX_len-1], P[i]);
-	}
-      }
-      *P[i] = '\0';
-    }
-  }
+  putPMXlines(&V);
   if (some_vocal && (nvoice > 0 || !final_paragraph)) {
     FORLIM = ninstr;
-    for (i = 1; i <= FORLIM; i++) {
-      assignLyrics(i, lyrassign);
+    for (j = 1; j <= FORLIM; j++) {
+      assignLyrics(j, lyrassign);
       if (*lyrassign != '\0') {
 	sprintf(STR2, "\\\\%s\\", lyrassign);
 	putLine(STR2);
@@ -773,8 +657,8 @@ static void musicParagraph(void)
     nbars++;
   if (nbars == 0 && multi_bar_rest)
     nbars = 1;
-  FORLIM = nbars;
-  for (bar_of_line = 1; bar_of_line <= FORLIM; bar_of_line++)
+  FORLIM1 = nbars;
+  for (bar_of_line = 1; bar_of_line <= FORLIM1; bar_of_line++)
     processOneBar(&V);
 }
 
@@ -795,7 +679,6 @@ static void doMusic(void)
   pmx_preamble_done = false;
   bar_no = 1;
   *repeat_sign = '\0';
-  first_par_PMX_len = 0;
   must_respace = false;
   do {
     final_paragraph = endOfInfile();
@@ -835,10 +718,10 @@ static void doMusic(void)
 static boolean control_paragraph, no_report_errors;
 
 
-static boolean isControlParagraph(char (*P)[256], short para_len)
+static boolean isControlParagraph(char (*P)[256], paragraph_index para_len)
 {
-  short i;
-  short commands = 0, labels = 0, voices = 0, guff = 0;
+  paragraph_index0 commands = 0, labels = 0, voices = 0, guff = 0;
+  paragraph_index0 i;
   char w[256];
 
 /* p2c: prepmx.pas: Note: Eliminated unused assignment statement [338] */
@@ -870,7 +753,6 @@ static void topOfPMXfile(void)
 	  this_version, this_version_date);
   putLine(STR2);
   putLine("\\let\\:=\\relax\\input musixtex\\:\\sepbarrules\\input pmx");
-  putLine("\\def\\Lrp#1{\\centerbar{\\liftpause{#1}}}");
 }
 
 
